@@ -3,9 +3,11 @@ Main interface for transfer service type definitions.
 
 Usage::
 
-    from mypy_boto3.transfer.type_defs import DescribedServerTypeDef
+    ```python
+    from mypy_boto3_transfer.type_defs import DescribedServerTypeDef
 
     data: DescribedServerTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
